/*
 * YouGrabber
 *
 * A lightweight, ncurses-based, multi-threaded command line YouTube.com
 * video downloader with proxy support, made from scratch in ANSI C.
 *
 * Copyright (C) 2006-2007 Quetzy Garcia, <quetzyg@users.sourceforge.net>
 * For news and updates, see <http://yougrabber.sourceforge.net/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DOWNLOAD_H
  #define DOWNLOAD_H 1
#endif

typedef struct __download D;

typedef enum
{
  DOWNLOAD_ERROR_VIDEO_UNAVAILABLE,
  DOWNLOAD_ERROR_VIDEO_REMOVED,
  DOWNLOAD_ERROR_IO,
  DOWNLOAD_ERROR_NETWORK,
  DOWNLOAD_OK_DOWNLOADING,
  DOWNLOAD_OK_FINISHED
} DownloadStatus;

typedef enum
{
  LOGIN_FAILED,
  LOGIN_SKIPPED,
  LOGIN_WAITING,
  LOGIN_OK
} LoginStatus;

/* create a new download and return pointer */
extern D *download_new(C *c_ptr, char *url);

/* free download resources (GFunc() type function) */
extern void download_free(gpointer data, gpointer user_data);

/* login into youtube and get cookie */
extern int download_cookie(C *config);

/* get download status */
extern int download_get_status(D *d_ptr);

/* get download network error */
extern char *download_get_network_error(D *d_ptr);

/* get download speed */
extern double download_get_speed(D *d_ptr);

/* get download time */
extern double download_get_time(D *d_ptr);

/* get download file name */
extern char *download_get_file_name(D *d_ptr);

/* get download current file size */
extern double download_get_file_size_now(D *d_ptr);

/* get download total file size */
extern double download_get_file_size_total(D *d_ptr);

/* get download video title */
extern char *download_get_video_title(D *d_ptr);

/* get download video URL */
extern char *download_get_video_url(D *d_ptr);
