/*
 * YouGrabber
 *
 * A lightweight, ncurses-based, multi-threaded command line YouTube.com
 * video downloader with proxy support, made from scratch in ANSI C.
 *
 * Copyright (C) 2006-2007 Quetzy Garcia, <quetzyg@users.sourceforge.net>
 * For news and updates, see <http://yougrabber.sourceforge.net/>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#include "common.h"

int main(int argc, char **argv)
{
  GList *d_list = NULL;
  C *c_ptr = NULL;
  I *i_ptr = NULL;
  int i;

  /* display usage when no URL is passed */
  if (argc < 2)
  {
    fprintf(stderr, "%s v%s - Copyright (C) %s <%s>\n\n"\
      "Usage: %s [YouTube video URL]...\n\n",
      YG_STRING, YG_VERSION, YG_AUTHOR, YG_EMAIL, basename(argv[0]));

    return EXIT_SUCCESS;
  }

  /* set configuration */
  if ((c_ptr = config_new()) == NULL)
  {
    fprintf(stderr, "%s v%s - Copyright (C) %s <%s>\n\n"\
      "insufficient memory to store configuration settings\n\n",
      YG_STRING, YG_VERSION, YG_AUTHOR, YG_EMAIL);

    return EXIT_FAILURE;
  }

  /* login into youtube and get cookie */
  config_set_youtube_login_status(c_ptr, download_cookie(c_ptr));

  /* create a download for each URL */
  for (i = 1; i < argc; ++i)
  {
    D *d_ptr = NULL;

    d_ptr = download_new(c_ptr, argv[i]);

    if (d_ptr != NULL)
      d_list = g_list_append(d_list, d_ptr);
  }

  /* set downloads in progress */
  dip_set(g_list_length(d_list));

  if (dip_get() < 1)
  {
    g_list_free(d_list);

    config_free(c_ptr);

    fprintf(stderr, "%s v%s - Copyright (C) %s <%s>\n\n"\
      "insufficient memory to store download data\n\n",
      YG_STRING, YG_VERSION, YG_AUTHOR, YG_EMAIL);

    return EXIT_FAILURE;
  }

  /* create user interface */
  if ((i_ptr = interface_new(c_ptr, d_list)) == NULL)
  {
    g_list_foreach(d_list, download_free, NULL);
    g_list_free(d_list);

    config_free(c_ptr);

    fprintf(stderr, "%s v%s - Copyright (C) %s <%s>\n\n"\
      "insufficient memory to start user interface\n\n",
      YG_STRING, YG_VERSION, YG_AUTHOR, YG_EMAIL);

    return EXIT_FAILURE;
  }

  interface_main_loop(i_ptr);
  interface_free(i_ptr);

  return EXIT_SUCCESS;
}
